<?php
	// Exit if accessed directly
	if ( !defined('ABSPATH')) exit;

/**
 * Header Template
 *
 * @file           header.php
 * @package        Patterns 
 * @author         Gabfire Themes
 */
?>
<!DOCTYPE html>
<!--[if IE 7]>
<html class="ie ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html class="ie ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>

<meta charset="<?php bloginfo('charset'); ?>" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, minimum-scale=1.0">

<title><?php wp_title('&#124;', true, 'right'); ?></title>

<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />

<?php
	if (!function_exists('gabfire_style_init')) {
		
		function gabfire_style_init() {
			wp_enqueue_style('bootstrap', get_template_directory_uri() .'/framework/bootstrap/css/bootstrap.css');
			wp_enqueue_style('bootstrap-responsive', get_template_directory_uri() .'/framework/bootstrap/css/bootstrap-responsive.css');
			wp_enqueue_style('gabfire-style', get_stylesheet_uri(), false);
			
			if(file_exists(get_stylesheet_directory() . '/custom.css')) { 			
				wp_enqueue_style('custom-style', get_stylesheet_directory_uri() .'/custom.css');		
			} elseif(file_exists(get_template_directory_uri() . '/custom.css')) {
				wp_enqueue_style('custom-style', get_template_directory_uri() .'/custom.css');	
			}
		}
	} 
	
	if (!is_admin()) {
		// load style files
		add_action( 'wp_print_styles', 'gabfire_style_init' );
	}

	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
	wp_head();

	/* For style files, look into framework/functions/misc-functions.php lines #15 - #36 */ 
	
	if(of_get_option('of_pt_customcolors', 0) == 1) { 
		get_template_part( 'css/customizedcss', '' );
	}
?>
 				
<!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
<!--[if lt IE 9]>
	<script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
	<link rel="stylesheet" type="text/css" media="screen" title="Stylesheet" href="<?php echo get_stylesheet_directory_uri(); ?>/css/ie-lt9.css" />
<![endif]-->

</head>

<body <?php body_class(); ?>>

<?php 
	$do_not_duplicate = '';
	global $do_not_duplicate; ?>

<div class="container">
	<div class="row">	
		<div id="header" class="span12">
			<div id="masthead">
				<div class="masthead_left">
					<?php if (intval(of_get_option('of_pt_nrmhead', 8)) > 0 ) { ?>
					<span class="masthead_caption"><?php echo of_get_option('of_pt_capmhead'); ?>&nbsp;</span>
					
					<ul id="js-news" class="js-hidden">
					<?php 
					$count = 1;
				
					if (of_get_option('of_pt_mheadtype') == 'mrecent') {
						$args = array(
						  'post__not_in'=> $do_not_duplicate,
						  'posts_per_page' => of_get_option('of_pt_nrmhead'),
						);
					}
					elseif (of_get_option('of_pt_mheadtype') == 'tagbased') {
						$args = array(
						  'post__not_in'=> $do_not_duplicate,
						  'posts_per_page' => of_get_option('of_pt_nrmhead'),
						  'tag_id' => of_get_option('of_pt_tagmhead')
						);
					}
					elseif (of_get_option('of_pt_mheadtype') == 'cfbased') {
						$args = array(
						  'post__not_in'=> $do_not_duplicate,
						  'post_type' => 'any',
						  'posts_per_page' => of_get_option('of_pt_nrmhead'),
						  'meta_key' => 'featured', 
						  'meta_value' => 'true'
						);
					}				
					else {
						$args = array(
						  'post__not_in'=> $do_not_duplicate,
						  'cat' => of_get_option('of_pt_catmhead'), 
						  'posts_per_page' => of_get_option('of_pt_nrmhead')
						);
					}
					$gab_query = new WP_Query();$gab_query->query($args); 
					while ($gab_query->have_posts()) : $gab_query->the_post();	
					if (of_get_option('of_dnd') == 1) { $do_not_duplicate[] = $post->ID; }
					?>
				
					<li class="news-item">
						<a href="<?php the_permalink() ?>" rel="bookmark" title="<?php printf( esc_attr__( 'Permalink to %s', 'gabfire' ), the_title_attribute( 'echo=0' ) ); ?>" ><?php the_title(); ?></a>
					</li>
					
					<?php $count++; endwhile; wp_reset_query(); ?>			
					</ul>
					<?php } ?>
				</div><!-- masthead_left -->
				
				<?php if ( of_get_option('of_loginlinks', 1) == 1 ) { ?>
				<p class="gab_logintools">
					<span class="gab_login"><?php wp_loginout(); ?></span>
					<?php if(!is_user_logged_in()) { ?>
					<span class="or"><?php _e('or','gabfire'); ?></span>
					<?php wp_register('<span class="gab_signup">','</span>',true); ?>
					<?php } ?>
				</p>
				<?php } ?>				
				
				<div class="clearfix"></div>
			</div>	

			<div id="logo-and-search">
			
				<div class="sitelogo" style="padding:<?php echo of_get_option('of_padding_top', 0); ?>px 0px <?php echo of_get_option('of_padding_bottom', 0); ?>px <?php echo of_get_option('of_padding_left', 0); ?>px;">	
					<?php if ( of_get_option('of_logo_type', 'text') == 'image') { ?>
						<h1>
							<a href="<?php echo home_url('/'); ?>" title="<?php bloginfo('description'); ?>">
								<img src="<?php echo of_get_option('of_logo'); ?>" alt="<?php bloginfo('name'); ?>" title="<?php bloginfo('name'); ?>"/>
							</a>
						</h1>
					<?php } else { ?>
						<h1>
							<a href="<?php echo home_url('/'); ?>" title="<?php bloginfo('description'); ?>"><?php echo of_get_option('of_logo1'); ?></a>
							<span><a href="<?php echo home_url('/'); ?>" title="<?php bloginfo('description'); ?>"><?php echo of_get_option('of_logo2'); ?></a></span>
						</h1>
					<?php } ?>
				</div><!-- .logo -->

				<div class="header-right<?php if ( of_get_option('of_pt_ad1') <> "" ) { ?> headerad<?php } ?>">
					<?php if ( of_get_option('of_pt_ad1') <> "" ) { ?>
					<div <?php if ( of_get_option('of_pt_ad1m') <> "" ) { echo 'style="margin-bottom:' . of_get_option('of_pt_ad1m') . 'px"'; } ?>>
						<?php gab_categoryad('header_728x90');  ?>
					</div>
					<?php } else { ?>
						<div id="search">
							<?php get_search_form(); ?>
						</div><!-- /search -->
						
						<div id="social_header">
							<ul>
								<?php if ( of_get_option('of_pt_mheadtwitter') <> "" ) { ?>
									<li><a class="gab_twitter masthead_social" href="<?php echo of_get_option('of_pt_mheadtwitter'); ?>" rel="nofollow" title="<?php esc_attr_e('Follow on Twitter','gabfire'); ?>"><?php _e('Twitter','gabfire'); ?></a></li>
								<?php } ?>
								
								<?php if ( of_get_option('of_pt_mheadfacebook') <> "" ) { ?>
									<li><a class="gab_facebook masthead_social" href="<?php echo of_get_option('of_pt_mheadfacebook'); ?>" rel="nofollow" title="<?php esc_attr_e('Connect on Facebook','gabfire'); ?>"><?php _e('Facebook','gabfire'); ?></a></li>
								<?php } ?>
								
								<?php if ( of_get_option('of_pt_mheadgplus') <> "" ) { ?>
									<li><a class="gab_gplus masthead_social" href="<?php echo of_get_option('of_pt_mheadgplus'); ?>" rel="nofollow" title="<?php esc_attr_e('Connect on Google+','gabfire'); ?>"><?php _e('Google+','gabfire'); ?></a></li>
								<?php } ?>
								
								<?php if ( of_get_option('of_pt_mheadlinkedin') <> "" ) { ?>
									<li><a class="gab_linkedin masthead_social" href="<?php echo of_get_option('of_pt_mheadlinkedin'); ?>" rel="nofollow" title="<?php esc_attr_e('Connect on LinkedIn','gabfire'); ?>"><?php _e('LinkedIn','gabfire'); ?></a></li>
								<?php } ?>

								<?php if ( of_get_option('of_pt_mheadvimeo') <> "" ) { ?>
									<li><a class="gab_vimeo masthead_social" href="<?php echo of_get_option('of_pt_mheadvimeo'); ?>" rel="nofollow" title="<?php esc_attr_e('Watch on Vimeo','gabfire'); ?>"><?php _e('Vimeo','gabfire'); ?></a></li>
								<?php } ?>
								
								<?php if ( of_get_option('of_pt_mheadytube') <> "" ) { ?>
									<li><a class="gab_ytube masthead_social" href="<?php echo of_get_option('of_pt_mheadytube'); ?>" rel="nofollow" title="<?php esc_attr_e('Watch on Youtube','gabfire'); ?>"><?php _e('Youtube','gabfire'); ?></a></li>
								<?php } ?>						
								
								<?php if ( of_get_option('of_pt_mheademail') <> "" ) { ?>
									<li><a class="gab_email masthead_social" href="<?php echo of_get_option('of_pt_mheademail'); ?>" rel="nofollow" title="<?php esc_attr_e('Subscribe to latest posts via email','gabfire'); ?>"><?php _e('Email','gabfire'); ?></a></li>
								<?php } ?>
								
								<?php if ( of_get_option('of_pt_sitefeed') == 1 ) { ?>
									<li><a class="gab_rss masthead_social" href="<?php if ( of_get_option('of_rssaddr') <> "" ) { echo of_get_option('of_rssaddr'); } else { echo bloginfo('rss2_url'); } ?>" rel="nofollow" title="<?php esc_attr_e('Subscribe to latest posts in RSS','gabfire'); ?>"><?php _e('RSS','gabfire'); ?></a></li>
								<?php } ?>
						 </ul>
						</div>
					<?php } ?>
				</div>
			</div><!-- #logo-and-search -->
			
			<div id="mainmenu">
				<ul class="mainnav menu">
					<li class="first<?php if(is_home() ) { ?> current-cat<?php } ?>"><a href="<?php echo home_url('/'); ?>" title="<?php bloginfo('description'); ?>"><i class="icon-home nav-icon"></i><?php _e('Home','gabfire'); ?></a></li>
					<?php
					/* mega dropdown starts */
					$cat_count = of_get_option('of_megadpnr');
					
					$options = array();
					for ($i=1; $i<=$cat_count;$i++) {
						if(0 < strlen($variable = of_get_option('of_mega'.$i))) {
							$options[] = $variable;
						}
					}
					$align = 1; /* Used to get value for align of dropdown navigation */
					foreach ($options as $id => $option)
					{
					?>
					
						<li class="megadp"><a href="<?php echo get_category_link($option);?>" class="drop"><?php echo get_cat_name($option); ?></a>
								
								<?php if (of_get_option('of_megaalign'.$align) == 1) { 
									$dropdown_align = 'align_right'; 
								} else {
									$dropdown_align = 'align_left'; 
								}
								?>
								
								<div class="dropdown_col <?php echo $dropdown_align; ?>"><!-- Begin 3 columns container -->
								
								<div class="dropdown_inner">							
									<ul class="greybox">
										<?php if (of_get_option('of_megadplinks'.$align) == 1) {
											wp_nav_menu( array('theme_location' => 'megadp-'.$align, 'container' => false, 'items_wrap' => '%3$s'));
										} else {
											wp_list_categories('depth=1&show_count=1&title_li=&child_of='.$option); 
										}  
										?>
										<li class="feed"><a href="<?php echo get_category_feed_link($option, ''); ?>"><?php _e('RSS Feed','gabfire'); ?></a></li>
									</ul>


									<div class="dropdown_entries">
										<?php
										$count = 1;
										$args = array(
										  'cat' => $option,
										  'posts_per_page' => 3
										);
										$gab_query = new WP_Query();$gab_query->query($args); 
										while ($gab_query->have_posts()) : $gab_query->the_post();	
										?>

											<div class="featuredpost<?php if($count == 3) { echo ' lastpost'; } ?>">
												<h2 class="posttitle<?php if( get_comments_number() > 10 ) { echo ' popular'; } ?>">
													<a href="<?php the_permalink() ?>" rel="bookmark" title="<?php printf( esc_attr__( 'Permalink to %s', 'gabfire' ), the_title_attribute( 'echo=0' ) ); ?>" ><?php the_title(); ?></a>
												</h2>
												<p>
													<?php
														gab_media(array(
															'name' => 'pt-primary_left',
															'imgtag' => 1,
															'link' => 1,
															'enable_video' => 0,
															'catch_image' => of_get_option('of_catch_img', 'false'),
															'enable_thumb' => 1,
															'resize_type' => 'c',
															'media_width' => 60, 
															'media_height' => 55, 
															'thumb_align' => 'alignleft',
															'enable_default' => 'false'
														));
													?>
													<?php echo string_limit_words(get_the_excerpt(),14); ?>&hellip;
												</p>
											</div><!-- .featuredpost -->
										<?php $count++; endwhile; wp_reset_query(); ?>
									</div><!-- dropdown entries -->
								</div><!-- dropdown_wrapper -->
							</div><!-- dropdown_col -->
						</li><!-- megadropdown li -->
					<?php  $align++; } /* mega dropdown ends */
				
					if(of_get_option('of_nav1', 0) == 1) { 
						wp_nav_menu( array('theme_location' => 'primary', 'container' => false, 'items_wrap' => '%3$s'));
					} else {
						wp_list_categories('orderby='. of_get_option('of_order_cats') .'&order='. of_get_option('of_sort_cats') .'&title_li=&exclude='. of_get_option('of_ex_cats'));
					}
					?>
				</ul>
			</div>
		</div><!-- header -->
	</div><!-- row -->