<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = $themename->{'Name'};
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 * 
 */

function optionsframework_options() {

	// VARIABLES
	$themename = wp_get_theme();
	$themename = $themename->{'Name'};
	$shortname = "of";
	$themeid = "_pt";
	
	// Test data
	$test_array = array(
	'one' => 'One',
	'two' => 'Two',
	'three' =>'Three',
	'four' => 'Four',
	'five' => 'Five'
	);
	
	// Background options
	$patterns_path = get_template_directory_uri() . '/framework/images/patterns/';
	$patterns_array = array(
	'none' => $patterns_path . 'none.jpg',
	'subtle-1' => $patterns_path . 'subtle-1.jpg',
	'subtle-2' => $patterns_path . 'subtle-2.jpg',
	'subtle-3' => $patterns_path . 'subtle-3.jpg',
	'subtle-4' => $patterns_path . 'subtle-4.jpg',
	'subtle-5' => $patterns_path . 'subtle-5.jpg',
	'subtle-6' => $patterns_path . 'subtle-6.jpg',
	'subtle-7' => $patterns_path . 'subtle-7.jpg',
	'subtle-8' => $patterns_path . 'subtle-8.jpg',
	'subtle-9' => $patterns_path . 'subtle-9.jpg',
	'subtle-10' => $patterns_path . 'subtle-10.jpg',
	'subtle-11' => $patterns_path . 'subtle-11.jpg',
	'subtle-12' => $patterns_path . 'subtle-12.jpg',
	'subtle-13' => $patterns_path . 'subtle-13.jpg',
	'subtle-14' => $patterns_path . 'subtle-14.jpg',
	'subtle-15' => $patterns_path . 'subtle-15.jpg',
	'subtle-16' => $patterns_path . 'subtle-16.jpg',
	'subtle-17' => $patterns_path . 'subtle-17.jpg',
	);
	
	// Multicheck Array
	$multicheck_array = array(
	'one' => 'French Toast',
	'two' => 'Pancake',
	'three' =>'Omelette',
	'four' => 'Crepe',
	'five' => 'Waffle'
	);	
	
	// Cycle2 Options
	$cycle2_slidefx = array(
		'fade' => 'Fade',
		'fadeout' => 'Fade-Out',
		'scrollHorz' => 'Scroll Horizontally',
		'none' => 'None'
	);	

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);
	
	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );
		
	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);	
	
	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath = get_template_directory_uri() . '/framework/admin/images/';
	
	//Default Arrays 
	$options_revealtype = array('OnMouseover', 'OnClick');
	$options_nr = array(0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20);
	$options_inslider = array("Disable", "Tag-based", "Site Wide");
	$options_sort = array("ASC" => 'asc', 'desc' => 'desc');
	$options_order = array('id' => "id", 'name' => 'name', "count" => "count");
	$options_logo = array('text' => "Text Based Logo", "image" => "Image Based Logo");
	$options_feaslide = array("scrollUp", "scrollDown", "scrollLeft", "scrollRight", "turnUp", "turnDown", "turnLeft", "turnRight", "fade");
	$options_feaslide_flex = array("fade", "slide");

	//Stylesheets Reader
	$alt_stylesheet_path = get_stylesheet_directory() . '/styles/';
	$alt_stylesheets = array();
	
	if ( is_dir($alt_stylesheet_path) ) {
		if ($alt_stylesheet_dir = opendir($alt_stylesheet_path) ) { 
			while ( ($alt_stylesheet_file = readdir($alt_stylesheet_dir)) !== false ) {
				if(stristr($alt_stylesheet_file, ".css") !== false) {
					$alt_stylesheets[] = $alt_stylesheet_file;
				}
			} 
		}
	}

	$options = array();
		
	$options[] = array( 'name' => 'General Settings', 'type' => 'heading');
	
		$url =  get_bloginfo('stylesheet_directory').'/framework/admin/images/';
		$options[] = array( 'name' => 'Select header style',
							'desc' => 'Set your header either to display a single image, logo and banner, or logo with quotes.',
							'id' => $shortname.'_header_type',
							'std' => 'logosearch',
							'type' => 'images',
							'options' => array(
								'logosearch' => $url . 'logo-search.gif',
								'logobanner' => $url . 'logobanner.gif',
								'singleimage' => $url . 'single-image.gif'));

		$options[] = array( 'name' => 'Header image (if single image selected)',
							'desc' => 'If single image option is selected as header type, upload an image 960px wide.',
							'id' => $shortname.'_himageurl',
							'type' => 'upload');
							
		$options[] = array( 'name' => 'Logo Type',
							'desc' => 'If text-based logo is selected, set sitename and tagline on WordPress settings page.',
							'id' => $shortname.'_logo_type',
							'std' => 'Text Based Logo',
							'type' => 'select',
							'options' => $options_logo); 

		$options[] = array( 'name' => 'Custom Logo',
							'desc' => 'If image-based logo is selected, upload a logo for your theme, or specify the image address of your online logo. (http://yoursite.com/logo.png) [Max Width: 360px]',
							'id' => $shortname.'_logo',
							'type' => 'upload');
							
		$options[] = array( 'name' => 'Text Logo',
							'desc' => 'If text-based logo is selected, enter text to display on first row.',
							'id' => $shortname.'_logo1',
							'type' => 'text');
							
		$options[] = array( 'desc' => 'If text-based logo is selected, enter text to display on second row.',
							'id' => $shortname.'_logo2',
							'type' => 'text');
							
		$options[] = array( 'name' => 'Logo Padding Top',
							'desc' => 'Set a padding value between logo and top line.',
							'id' => $shortname.'_padding_top',
							'std' => 15,
							'class' => 'mini',
							'type' => 'text');

		$options[] = array( 'name' => 'Logo Padding Bottom',
							'desc' => 'Set a padding value between logo and bottom line.',
							'id' => $shortname.'_padding_bottom',
							'std' => 15,
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( 'name' => 'Logo Padding Left',
							'desc' => 'Set a padding value between logo and left line.',
							'id' => $shortname.'_padding_left',
							'std' => 0,
							'type' => 'text');
							
		$options[] = array( 'name' => 'Custom Favicon',
							'desc' => 'Upload a 16px x 16px Png/Gif image that will represent your website\'s favicon.',
							'id' => $shortname.'_custom_favicon',
							'type' => 'upload'); 
							
		$options[] = array( 'name' => 'RSS',
							'desc' => 'Link to third party feed handler. <br/> [http://www.url.com]',
							'id' => $shortname.'_rssaddr',
							'type' => 'text'); 				
		
		$options[] = array( 'name' => 'Tracking Code',
							'desc' => 'Paste your Google Analytics (or other) tracking code here. This will be added into the footer template of your theme.',
							'id' => $shortname.'_google_analytics',
							'type' => 'textarea'); 						
							
	$options[] = array( 'name' => 'Navigation', 'type' => 'heading');

		$options[] = array( 'name' => 'Custom Navigation',
							'desc' => 'Enable custom menus for main navigation. [If selected, create a <a href="nav-menus.php" target="_blank">custom menu</a>]',
							'id' => $shortname.'_nav1',
							'std' => 0,
							'type' => 'checkbox');
													
		$options[] = array( 'name' => 'Custom Navigation',
							'desc' => 'Enable custom menus for footer navigation. [If selected, create a <a href="nav-menus.php" target="_blank">custom menu</a>]',
							'id' => $shortname.'_nav2',
							'std' => 0,
							'type' => 'checkbox');
	
		$options[] = array( 'name' => 'Sort Categories',
							'desc' => 'Display categories in ascending or descending order',
							'id' => $shortname.'_sort_cats',
							'type' => 'select',
							'class' => 'mini',
							'options' => $options_sort);

		$options[] = array( 'name' => 'Order Categories',
							'desc' => 'Display categories in alphabetical order, by category ID, or by the count of posts',
							'id' => $shortname.'_order_cats',
							'std' => 'name',
							'type' => 'select',
							'class' => 'mini',
							'options' => $options_order);
							
		$options[] = array( 'name' => 'Exclude Categories',
							'desc' => 'ID number of cat(s) to exclude from navigation (eg 1,2,3,4) <a href="http://www.gabfirethemes.com/how-to-check-category-ids/" target="_blank">How check category/page ID</a>',
							'id' => $shortname.'_ex_cats',
							'class' => 'mini',
							'type' => 'text'); 
							
		$options[] = array( 'name' => 'Exclude Pages from masthead nav',
							'desc' => 'ID number of page(s) to exclude from navigation (eg 1,2,3,4) <a href="http://www.gabfirethemes.com/how-to-check-category-ids/" target="_blank">How check category/page ID</a>',
							'id' => $shortname.'_ex_pages_mhead',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( 'name' => 'Exclude Pages from secondary nav',
							'desc' => 'ID number of page(s) to exclude from navigation (eg 1,2,3,4) <a href="http://www.gabfirethemes.com/how-to-check-category-ids/" target="_blank">How check category/page ID</a>',
							'id' => $shortname.'_ex_pages',
							'class' => 'mini',
							'type' => 'text');
													
		$options[] = array( 'name' => 'Masthead Navigation Social Links Setup',
							'desc' => 'Enter the link of your account below into input fields in order to display a link to your social accounts. You can leave empty to disable any of social sites below',
							'type' => 'info');							
							
		$options[] = array( "desc" => "Link to Facebook account. <br/> [http://www.facebook.com/gabfire]",
							"id" => $shortname.$themeid."_mheadfacebook",
							"std" => "",
							"type" => "text"); 
							
		$options[] = array( "desc" => "Link to Twitter Account. <br/> [http://www.twitter.com/gabfirethemes]",
							"id" => $shortname.$themeid."_mheadtwitter",
							"std" => "",
							"type" => "text"); 
							
		$options[] = array( "desc" => "Link to Google+ Account. <br/> [https://plus.google.com/106104916131754615481/posts]",
							"id" => $shortname.$themeid."_mheadgplus",
							"std" => "",
							"type" => "text"); 

		$options[] = array( "desc" => "Link to Vimeo Account. <br/> [http://vimeo.com/gabfire]",
							"id" => $shortname.$themeid."_mheadvimeo",
							"std" => "",
							"type" => "text"); 
							
		$options[] = array( "desc" => "Link to Youtube Account. <br/> [http://www.youtube.com/user/gabfirethemes]",
							"id" => $shortname.$themeid."_mheadytube",
							"std" => "",
							"type" => "text");
							
		$options[] = array( "desc" => "Link to LinkedIn Account. <br/> [http://www.linkedin.com/company/gabfire-themes]",
							"id" => $shortname.$themeid."_mheadlinkedin",
							"std" => "",
							"type" => "text"); 
							
		$options[] = array( "desc" => "Email subscribe link. <br/> [http://feedburner.google.com/fb/a/mailverify?uri=gabfirethemes]",
							"id" => $shortname.$themeid."_mheademail",
							"std" => "",
							"type" => "text"); 							
						
		$options[] = array( "desc" => "Display a link to site feeds on masthead navigation",
							'id' => $shortname.$themeid.'_sitefeed',
							"std" => 1,
							"type" => "checkbox");						

	$options[] = array( 'name' => 'Mega Dropdown', 'type' => 'heading');							

		$options[] = array( 'desc' => 'Number of mega dropdown items to use',
						'id' => $shortname.'_megadpnr',
						'std' => 0,
						'class' => 'mini',
						'type' => 'select',
						'options' => array(0,1,2,3,4,5,6,7,8,9,10)); 		
	
		$options[] = array( 'name' => 'Mega Dropdown #1',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega1',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign1',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks1',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( 'name' => 'Mega Dropdown #2',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega2',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign2',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks2',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( 'name' => 'Mega Dropdown #3',
								'desc' => 'Category ID',
							'id' => $shortname.'_mega3',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign3',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks3',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( 'name' => 'Mega Dropdown #4',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega4',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign4',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks4',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( 'name' => 'Mega Dropdown #5',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega5',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign5',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks5',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( 'name' => 'Mega Dropdown #6',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega6',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign6',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks6',
							"std" => 0,
							"type" => "checkbox");
							
		$options[] = array( 'name' => 'Mega Dropdown #7',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega7',
							'class' => 'mini',
							'type' => 'text');

		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign7',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks7',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( 'name' => 'Mega Dropdown #8',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega8',
							'class' => 'mini',
							'type' => 'text');
														
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign8',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks8',
							"std" => 0,
							"type" => "checkbox");	
														
		$options[] = array( 'name' => 'Mega Dropdown #9',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega9',
							'class' => 'mini',
							'type' => 'text');
							
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign9',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks9',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( 'name' => 'Mega Dropdown #10',
							'desc' => 'Category ID',
							'id' => $shortname.'_mega10',
							'class' => 'mini',
							'type' => 'text');
									
		$options[] = array( "desc" => "Align right, if unchecked dropdown wrapper will be aligned left",
							'id' => $shortname.'_megaalign10',
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "desc" => "Replace subcategory links with a custom menu [If selected, create a <a href='nav-menus.php' target='_blank'>custom menu</a>]",
							'id' => $shortname.'_megadplinks10',
							"std" => 0,
							"type" => "checkbox");	
														
	$options[] = array( 'name' => 'Categories', 'type' => 'heading');
		$options[] = array( "name" => "Do not duplicate posts",
							"desc" => "Regardless of category selections, do not duplicate posts on homepage. This prevents the same post from appearing in multiple sections (good for SEO)",
							"id" => $shortname."_dnd",
							"std" => 0,
							"type" => "checkbox");	
	
		$options[] = array( 'name' => 'Masthead Latest News',
							'desc' => 'Select a base query type to determine how this content area is populated',
							'id' => $shortname.$themeid.'_mheadtype',
							'std' => "catbased",
							'type' => "images",
							'options' => array(
								'catbased' => $imagepath . 'fea-category.gif',
								'cfbased' => $imagepath . 'fea-customfield.gif',
								'mrecent' => $imagepath . 'fea-recent.gif',
								'tagbased' => $imagepath . 'fea-tag.gif'));
	
		$options[] = array(
			'desc' => 'If base query type is Category or Tag-based, please identify the category or tag. </br>If base query type is Custom Field, posts which are marked as featured (checkbox labeled as <strong>Is Featured</strong> is enabled on <strong>Add/Edit Post</strong> screen) will be displayed).',
			'type' => 'info');	
	
		$options[] = array( 'desc' => 'If category based: Select a category for entries.',
							'id' => $shortname.$themeid.'_catmhead',
							'type' => 'select',
							'options' => $options_categories);
														
		$options[] = array( 'desc' => 'If tag based: Select a tag for entries.',
							'id' => $shortname.$themeid.'_tagmhead',
							'type' => 'text');

		$options[] = array( 'desc' => 'Number of Entries to display',
							'id' => $shortname.$themeid.'_nrmhead',
							'std' => 8,
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. Enter a caption to display on masthad before post title.',
							'id' => $shortname.$themeid.'_capmhead',
							'std' => 'Latest News',	
							'type' => 'text');	
	
		$options[] = array( 'name' => 'Featured Collage',
							'desc' => 'Select a base query type to determine how this content area is populated',
							'id' => $shortname.$themeid.'_featype',
							'std' => "catbased",
							'type' => "images",
							'options' => array(
								'catbased' => $imagepath . 'fea-category.gif',
								'cfbased' => $imagepath . 'fea-customfield.gif',
								'mrecent' => $imagepath . 'fea-recent.gif',
								'tagbased' => $imagepath . 'fea-tag.gif'));
	
		$options[] = array(
			'desc' => 'If base query type is Category or Tag-based, please identify the category or tag. </br>If base query type is Custom Field, posts which are marked as featured (checkbox labeled as <strong>Is Featured</strong> is enabled on <strong>Add/Edit Post</strong> screen) will be displayed).',
			'type' => 'info');		
	
		$options[] = array( 'desc' => 'If category based: Select a category for entries.',
							'id' => $shortname.$themeid.'_cat',
							'type' => 'select',
							'options' => $options_categories);

		$options[] = array( 'desc' => 'If tag based: Select a tag for entries.',
							'id' => $shortname.$themeid.'_tag',
							'type' => 'text');

		$options[] = array( 'desc' => 'Number of Entries to display - Set as 0 or 8',
							'id' => $shortname.$themeid.'_nr',
							'std' => 8,
							'class' => 'mini',
							'type' => 'select',
							'options' => array("0" => "0", "8" => "8"));
						
							
	
		$options[] = array( 'name' => 'Left hand below featured collage',
							'desc' => 'Select a category for entries.',
							'id' => $shortname.$themeid.'_cat1',
							'type' => 'select',
							'options' => $options_categories);

		$options[] = array( 'desc' => 'Number of Entries to display',
							'id' => $shortname.$themeid.'_nr1',
							'std' => 4,
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr); 
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_cap1',
							'type' => 'text');	
			
		$options[] = array( "name" => "Primary Content Mid Column - Top",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_cat2",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);
							
		$options[] = array( "desc" => "Number of posts to display with thumbnail + excerpt on left hand of primary mid section.",
							"id" => $shortname.$themeid."_nr2_a",
							"std" => "1",
							"class" => "mini",
							"type" => "text"); 	
							
		$options[] = array( "desc" => "Number of posts to display w/out thumbnail on right hand of primary mid column",
							"id" => $shortname.$themeid."_nr2_b",
							"std" => "1",
							"class" => "mini",
							"type" => "text"); 		
							
		$options[] = array( "desc" => "Number of posts to display on right block of primary mid section.",
							"id" => $shortname.$themeid."_nr2_c",
							"std" => "3",
							"class" => "mini",
							"type" => "text"); 			
														
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_cap2',
							'type' => 'text');	
							
		$options[] = array( 'name' => 'Right hand below featured collage',
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_cat3",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to display.",
							"id" => $shortname.$themeid."_nr3",
							"std" => "8",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr); 
							
		$options[] = array( "desc" => "Display a thumbnail after every ..... entry/entries.",
							"id" => $shortname.$themeid."_dt3",
							"std" => "3",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr); 

		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_cap3',
							'type' => 'text');	
														
		/*Secondary Content Left Column */
		$options[] = array( "name" => "Secondary Content Left Column",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_cat4",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to without thumbs but with big headlines.",
							"id" => $shortname.$themeid."_nr4a",
							"std" => "0",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( "desc" => "Number of entries to display with small thumbs.",
							"id" => $shortname.$themeid."_nr4b",
							"std" => "0",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( "desc" => "Number of entries to display with big thumbs.",
							"id" => $shortname.$themeid."_nr4c",
							"std" => "4",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_cap4',
							'type' => 'text');
							
							
		/*Secondary Content Right Column*/
		$options[] = array( "name" => "Secondary Content Right Column - top",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_cat5",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to display.",
							"id" => $shortname.$themeid."_nr5",
							"std" => "5",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_cap5',
							'type' => 'text');
							
		$options[] = array( 'name' => 'Secondary Content Right Column - bottom slider',
							'desc' => 'Select a category for entries.',
							'id' => $shortname.$themeid.'_catmedia',
							'type' => 'select',
							'options' => $options_categories);

		$options[] = array( 'desc' => 'Number of Entries to display',
							'id' => $shortname.$themeid.'_nrmedia',
							'std' => 1,
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr); 			

		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_capmedia',
							'type' => 'text');							

		/*Subnews 1st col */
		$options[] = array( "name" => "Subnews 1x4",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_subcat1",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to display.",
							"id" => $shortname.$themeid."_subnr1",
							"std" => "5",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_subcap1',
							'type' => 'text');

		/*Subnews 2nd col */
		$options[] = array( "name" => "Subnews 2x4",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_subcat2",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to display.",
							"id" => $shortname.$themeid."_subnr2",
							"std" => "5",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_subcap2',
							'type' => 'text');			

		/*Subnews 3rd col */
		$options[] = array( "name" => "Subnews 3x4",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_subcat3",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to display.",
							"id" => $shortname.$themeid."_subnr3",
							"std" => "5",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_subcap3',
							'type' => 'text');		

		/*Subnews 4th col */
		$options[] = array( "name" => "Subnews 4x4",
							"desc" => "Select a category.",
							"id" => $shortname.$themeid."_subcat4",
							"std" => "",
							"type" => "select",
							"options" => $options_categories);

		$options[] = array( "desc" => "Number of entries to display.",
							"id" => $shortname.$themeid."_subnr4",
							"std" => "5",
							'class' => 'mini',
							'type' => 'select',
							'options' => $options_nr);	
							
		$options[] = array( 'desc' => 'Caption. If you leave this empty; category name will be used as caption.',
							'id' => $shortname.$themeid.'_subcap4',
							'type' => 'text');									
							
$options[] = array( "name" => "Sliders", "type" => "heading");

			$options[] = array( "name" => "Inner-Page Slider",
								"desc" => "Automatically create a slideshow of uploaded photos in post entries to be displayed below post title. [Note: Inner-Page options include a) displaying slider site-wide b) tag-based c) or to disable completely].",
								"id" => $shortname."_inslider",
								"std" => "Disable",
								"type" => "select",
								"class" => "mini",
								"options" => $options_inslider);
								
			$options[] = array( "desc" => "If tag-based option is selected, display posts assigned this tag to be shown in inner-page slider. <br/> [Note: Posts with multiple image attachments and assigned this tag will display an inner-page slider].",
								"id" => $shortname."_inslider_tag",
								"std" => "",
								"class" => "mini",
								"type" => "text");
							
			$options[] = array( "desc" => "Slide function.",
								"id" => $shortname."_inner_slidefx",
								"std" => 'fade',
								"type" => "select",
								"options" => $cycle2_slidefx);
								
			$options[] = array( "desc" => "Enable auto rotation for innerpage slider.",
								"id" => $shortname."_inner_rotate",
								"std" => 0,
								"type" => "checkbox");	
								
			$options[] = array( "desc" => "Speed on transition (in miliseconds - 1000 = 1sec)",
								"id" => $shortname.$themeid."_inner_speed",
								"std" => "200",
								"class" => "mini",
								"type" => "text");					
							
	$options[] = array( 'name' => 'Image Handling', 'type' => 'heading');

		$options[] = array( 'name' => 'Catch First Image',
							'desc' => 'If enabled, built-in theme functions will scan post from top to bottom, catch the first image, and auto-generate a thumbnail for posts that do not have an image attached or custom field defined.',
							'id' => $shortname.'_catch_img',
							'std' => 0,
							'type' => 'checkbox');
							
		$options[] = array( 'name' => 'TimThumb or WordPress Post Thumbnails',
							'desc' => 'Disable TimThumb and use WordPress Post Thumbnails instead [WPMU Mode] [Check only if you are having problems with front page thumbnails].',
							'id' => $shortname.'_wpmumode',
							'std' => 0,
							'type' => 'checkbox');	
							
	$options[] = array( 'name' => 'Footer Options', 'type' => 'heading');
		
	
		$options[] = array( 'name' => 'Enable Custom Footer (Left)',
							'desc' => 'Activate to add the custom text on footer.',
							'id' => $shortname.'_footer1',
							'type' => 'checkbox'); 			
			
		$options[] = array( 'name' => 'Custom Text (Left)',
							'desc' => 'Custom HTML and Text that will appear in the footer of your theme.',
							'id' => $shortname.'_footer1_text',
							
							'type' => 'textarea');
								
		$options[] = array( 'name' => 'Enable Custom Footer (Right)',
							'desc' => 'Activate to add the custom text on footer.',
							'id' => $shortname.'_footer2',
							'id' => $shortname.'_footer2',
							'type' => 'checkbox'); 

		$options[] = array( 'name' => 'Custom Text (Right)',
							'desc' => 'Custom HTML and Text that will appear in the footer of your theme.',
							'id' => $shortname.'_footer2_text',
							
							'type' => 'textarea');

	$options[] = array( 'name' => 'Manage Ads', 'type' => 'heading');	
				
		$options[] = array( 'name' => 'Header 728px or 468px ad',
						'desc' => 'If an add code is entered into this box, it will remove the search box and social links from the header of site and display the ad on right hand of logo.',
						'id' => $shortname.$themeid.'_ad1',
						'type' => 'textarea');	
						
		$options[] = array( 'desc' => 'Set a margin value between header ad and bottom navigation.',
							'id' => $shortname.$themeid.'_ad1m',
							'std' => 0,
							'class' => 'mini',
							'type' => 'text');						
				
		$options[] = array( 'name' => 'Homepage - 160x600',
						'desc' => 'Below collage right column - 160x600 ad code',
						'id' => $shortname.$themeid.'_ad2',
						'type' => 'textarea');	

							
		$options[] = array( 'name' => 'Homepage - 300x250',
						'desc' => 'Below collage left column- 300x250 ad code',
						'id' => $shortname.$themeid.'_ad4',
						'type' => 'textarea');	
		
		$options[] = array( 'desc' => 'Set a margin value between banner and the widget below banner.',
							'id' => $shortname.$themeid.'_ad4m',
							'std' => 0,
							'class' => 'mini',
							'type' => 'text');

		$options[] = array( 'name' => 'Homepage - 468x60',
						'desc' => 'homepage 468x60 ad code',
						'id' => $shortname.$themeid.'_ad3',
						'type' => 'textarea');	
						
		$options[] = array( 'name' => 'Footer - 300xAny Left',
						'desc' => 'Footer 300xAny ad code',
						'id' => $shortname.$themeid.'_ad5',
						'type' => 'textarea');	
						
		$options[] = array( 'name' => 'Footer - 300xAny Mid',
						'desc' => 'Footer 300xAny ad code',
						'id' => $shortname.$themeid.'_ad6',
						'type' => 'textarea');	
						
		$options[] = array( 'name' => 'Footer - 300xAny Right',
						'desc' => 'Footer 300xAny ad code',
						'id' => $shortname.$themeid.'_ad7',
						'type' => 'textarea');	
							
		$options[] = array( 'name' => 'Right Sidebar Templ - 468x60',
						'desc' => 'Right Sidebar Templ - 468x60 ad code',
						'id' => $shortname.$themeid.'_ad8',
						'type' => 'textarea');	

		$options[] = array( 'name' => 'Right Sidebar Templ - Bottom Left Sidebar - 300x250 - top',
						'desc' => 'Right Sidebar Templ - Bottom Left Sidebar 300x250 ad code',
						'id' => $shortname.$themeid.'_ad9',
						'type' => 'textarea');	

		$options[] = array( 'name' => 'Right Sidebar Templ - Bottom Left Sidebar - 300x250 - bottom',
						'desc' => 'Right Sidebar Templ - Bottom Left Sidebar 300x250 ad code',
						'id' => $shortname.$themeid.'_ad10',
						'type' => 'textarea');	

		$options[] = array( 'name' => 'Right Sidebar Templ - Bottom Right Sidebar - 160x600',
						'desc' => 'Right Sidebar Templ - Bottom Right Sidebar 160x600 ad code',
						'id' => $shortname.$themeid.'_ad11',
						'type' => 'textarea');
						
		$options[] = array( 'name' => '3 col template left col sidebar - 160x600',
						'desc' => '3 col template left col sidebar (where post displays on mid column) 160x600 ad code',
						'id' => $shortname.$themeid.'_ad12',
						'type' => 'textarea');	

		$options[] = array( 'name' => '3 col template right col sidebar - 300x250 - top',
						'desc' => '3 col template (where post displays on mid column) right col sidebar 300x250 ad code',
						'id' => $shortname.$themeid.'_ad14',
						'type' => 'textarea');						
						
		$options[] = array( 'name' => '3 col template right col sidebar - 300x250 - bottom',
						'desc' => '3 col template (where post displays on mid column) right col sidebar 300x250 ad code',
						'id' => $shortname.$themeid.'_ad13',
						'type' => 'textarea');	
							
	$options[] = array( 'name' => 'Miscellaneous', 'type' => 'heading');
		$options[] = array(	'name' => '2 col category template',
							'desc' => 'ID number of cat(s) to use 2 cols category template Separate with comma if more than 1 category is entered. (ex: 1,5,99)',
							'id' => $shortname.$themeid.'_2col',
							'class' => 'mini',
							'type' => 'text'); 	
							
		$options[] = array(	'name' => '3 Column category template',
							'desc' => 'ID number of cat(s) to use 3 cols category template. Separate with comma if more than 1 category is entered. (ex: 1,5,99)',
							'id' => $shortname.$themeid.'_3col',
							'class' => 'mini',
							'type' => 'text'); 	
							
		$options[] = array(	'name' => '4 Column category template',
							'desc' => 'ID number of cat(s) to use 4 cols gallery template. Separate with comma if more than 1 category is entered. (ex: 1,5,99)',
							'id' => $shortname.$themeid.'_4col',
							'class' => 'mini',
							'type' => 'text'); 	
							
		$options[] = array(	'name' => 'Top-slider category template',
							'desc' => 'ID number of cat(s) to use category template with top slider. Separate with comma if more than 1 category is entered. (ex: 1,5,99) IMPORTANT: This category layout will not look correct unless there are at least 12 posts in the category and settings -> reading -> blog posts section is set to 12.',
							'id' => $shortname.$themeid.'_w_slider',
							'class' => 'mini',
							'type' => 'text'); 	

		$options[] = array( "name" => "Login - Signup links",
							"desc" => "Display login and signup links on masthead.",
							"id" => $shortname."_loginlinks",
							"std" => 0,
							"type" => "checkbox");	

		$options[] = array( "name" => "Featured Image Post Display",
							"desc" => "Auto resize and display featured image on single post - above entry.",
							"id" => $shortname."_autoimage",
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( "name" => "Facebook Meta Tags",
							"desc" => "Extract Facebook meta tags on header [Enable only if you are going to use Gabfire Share Widget]",
							"id" => $shortname."_fbonhead",
							"std" => 0,
							"type" => "checkbox");						

		$options[] = array( "name" => "Shortcodes",
							"desc" => "Enable shortcodes functionality",
							"id" => $shortname."_shortcodes",
							"std" => 0,
							"type" => "checkbox");	
							
		$options[] = array( 'name' => 'Widget Map',
							'desc' => 'Display the location of widgets on front page. After reviewing widget locations be sure to disable this option.',
							'id' => $shortname.'_widget',
							'std' => 0,
							'type' => 'checkbox');
							
	$options[] = array( 'name' => 'Custom Styling', 'type' => 'heading');	
	
		$options[] = array( 'name' => 'Custom CSS',
							'desc' => 'Quickly add some CSS to your theme by adding it to this block.',
							'id' => $shortname.'_custom_css',
							'type' => 'textarea');		
		
		$options[] = array( 'name' => 'Custom Styles',
							'desc' => 'This is a master trigger to enable/disable all custom styles',
							'id' => $shortname.$themeid.'_customcolors',
							'std' => 0,
							'type' => 'checkbox');	
		
		$options[] = array( 'name' => 'Body Font and Background',
							'desc' => 'Change body background and font style',
							'id' => $shortname.$themeid.'_bodytype',
							'std' => 0,
					
							'type' => 'checkbox');
					
		$options[] = array( 'name' => 'Select a Background',
							'desc' => 'Select a background.',
							'id' => $shortname.'_sitebg',
							'std' => 'none',
							'type' => "images",
						
							'options' => $patterns_array);							
					
		$options[] = array( 'name' => 'Body Font Setting',
							'desc' => 'Specify the body font properties',
							'id' => $shortname.$themeid.'_body_font',
							
							'std' => array('size' => '12px','face' => 'PT Sans, Tahoma, sans-serif','style' => 'normal','color' => '#555555'),
							'type' => 'typography'); 
			
		$options[] = array( 'name' => 'Primary and Secondary Colors',
							'desc' => 'Change primary and secondary color of theme',
							'id' => $shortname.$themeid.'_mscolors',
							
							'std' => 0,
							'type' => 'checkbox');		
							
		$options[] = array( 'desc' => 'Primary Theme Color',
							'id' => $shortname.$themeid.'_primaryclr',
							
							'type' => 'color');
							
		$options[] = array( 'desc' => 'Secondary Theme Color',
							'id' => $shortname.$themeid.'_secondaryclr',
						
							'type' => 'color');
		
		$options[] = array( 'name' => 'Change Post Title Font Settings',
							'desc' => 'Change Post Title Font Settings',
							'id' => $shortname.$themeid.'_posttitletype',
							
							'std' => 0,
							'type' => 'checkbox');
							
		$options[] = array( 'name' => 'PostTitle Font Setting',
							'desc' => 'Specify the title font properties',
							'id' => $shortname.$themeid.'_title_font',
							
							'std' => array('size' => '12px','face' => 'PT Sans, Tahoma, sans-serif','style' => 'normal','color' => '#555555'),
							'type' => 'typography');
							
			$options[] = array( 'desc' => 'Post title link color',
								'id' => $shortname.$themeid.'_ptaclr',
								
								'type' => 'color');

			$options[] = array( 'desc' => 'Post title hovered link color',
								'id' => $shortname.$themeid.'_ptahovclr',
								
								'type' => 'color');

		$options[] = array( 'name' => 'Change Category and Widget Titles',
							'desc' => 'Change Category and Widget Titles',
							'id' => $shortname.$themeid.'_widgetcattype',
							
							'std' => 0,
							'type' => 'checkbox');
							
		$options[] = array( 'name' => 'WidgetTitle Font Setting',
							'desc' => 'Specify the title font properties',
							'id' => $shortname.$themeid.'_widgettitle',
							'std' => array('size' => '12px','face' => 'PT Sans, Tahoma, sans-serif','style' => 'normal','color' => '#555555'),
							
							'type' => 'typography');
							
		$options[] = array( 'name' => 'Category Captions Font Setting - Frontpage',
							'desc' => 'Specify the title font properties',
							'id' => $shortname.$themeid.'_catclr',
							'std' => array('size' => '12px','face' => 'PT Sans, Tahoma, sans-serif','style' => 'normal','color' => '#555555'),
							
							'type' => 'typography');				

		$options[] = array( 'name' => 'Change Text Logo Font Settings',
							'desc' => 'Change Text Logo Font Settings',
							'id' => $shortname.$themeid.'_logoslogantype',
							'std' => 0,
							
							'type' => 'checkbox');
								
			$options[] = array( 'desc' => 'If text based logo is activated, select a color for first row text',
								'id' => $shortname.$themeid.'_sloganclr1',
								
								'type' => 'color');			
								
			$options[] = array( 'desc' => 'If text based logo is activated, select a color for second row text',
								'id' => $shortname.$themeid.'_sloganclr2',
								
								'type' => 'color');	

		$options[] = array( 'name' => 'Change Main Nav Font Settings',
							'desc' => 'Change Main Nav Font Settings',
							'id' => $shortname.$themeid.'_mnavtype',
							'std' => 0,
							
							'type' => 'checkbox');
							
			$options[] = array( 'desc' => 'Main navigation active color',
								'id' => $shortname.$themeid.'_mnactlc',
								
								'type' => 'color');	
								
			$options[] = array( 'desc' => 'Main navigation hover color',
								'id' => $shortname.$themeid.'_mnavclr',
								
								'type' => 'color');	

			$options[] = array( 'desc' => 'Main navigation active/hover background color',
								'id' => $shortname.$themeid.'_linkhvrclr',
								
								'type' => 'color');
								
		$options[] = array( 'name' => 'Change Footer Nav Font Settings',
							'desc' => 'Change Footer Nav Font Settings',
							'id' => $shortname.$themeid.'_fnavtype',
							'std' => 0,
							
							'type' => 'checkbox');
			$options[] = array( 'desc' => 'Footer navigation active color',
								'id' => $shortname.$themeid.'_fnactlc',
								
								'type' => 'color');	
								
			$options[] = array( 'desc' => 'Footer navigation hover color',
								'id' => $shortname.$themeid.'_fnavclr',
								
								'type' => 'color');	
		
	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
 		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}
	
	$('#of_footer1').click(function() {
 		$('#section-of_footer1_text').fadeToggle(400);
	});

	if ($('#of_footer1:checked').val() !== undefined) {
		$('#section-of_footer1_text').show();
	}
	
	$('#of_footer2').click(function() {
 		$('#section-of_footer2_text').fadeToggle(400);
	});

	if ($('#of_footer2:checked').val() !== undefined) {
		$('#section-of_footer2_text').show();
	}
	
	$('#of_en_newsletter').click(function() {
 		$('#section-of_title').fadeToggle(400);
		$('#section-of_subcap').fadeToggle(400);
		$('#section-of_text1').fadeToggle(400);
		$('#section-of_text2').fadeToggle(400);
		$('#section-of_feedid').fadeToggle(400);
		$('#section-of_sublogo').fadeToggle(400);
		$('#section-of_sublogomargin_top').fadeToggle(400);
		$('#section-of_sublogomargin_bottom').fadeToggle(400);
		$('#section-of_sublogomargin_left').fadeToggle(400);		
	});

	if ($('#of_en_newsletter:checked').val() !== undefined) {
 		$('#section-of_title').show();
		$('#section-of_subcap').show();
		$('#section-of_text1').show();
		$('#section-of_text2').show();
		$('#section-of_feedid').show();
		$('#section-of_sublogo').show();
		$('#section-of_sublogomargin_top').show();
		$('#section-of_sublogomargin_bottom').show();
		$('#section-of_sublogomargin_left').show();	
	}	
		
	$('#of_pt_customcolors').click(function() {
		$('#section-of_pt_bodytype').fadeToggle(400);
		$('#section-of_sitebg').fadeToggle(400);
		$('#section-of_pt_body_font').fadeToggle(400);
		$('#section-of_pt_mscolors').fadeToggle(400);
		$('#section-of_pt_primaryclr').fadeToggle(400);
		$('#section-of_pt_secondaryclr').fadeToggle(400);
		$('#section-of_pt_posttitletype').fadeToggle(400);
		$('#section-of_pt_title_font').fadeToggle(400);
		$('#section-of_pt_ptaclr').fadeToggle(400);
		$('#section-of_pt_ptahovclr').fadeToggle(400);
		$('#section-of_pt_widgetcattype').fadeToggle(400);
		$('#section-of_pt_widgettitle').fadeToggle(400);
		$('#section-of_pt_catclr').fadeToggle(400);
		$('#section-of_pt_logoslogantype').fadeToggle(400);
		$('#section-of_pt_sloganclr1').fadeToggle(400);
		$('#section-of_pt_sloganclr2').fadeToggle(400);
		$('#section-of_pt_mnavtype').fadeToggle(400);
		$('#section-of_pt_mnactlc').fadeToggle(400);
		$('#section-of_pt_mnavclr').fadeToggle(400);
		$('#section-of_pt_linkhvrclr').fadeToggle(400);
		$('#section-of_pt_fnavtype').fadeToggle(400);
		$('#section-of_pt_fnactlc').fadeToggle(400);
		$('#section-of_pt_fnavclr').fadeToggle(400);	
	});

	if ($('#of_pt_customcolors:checked').val() !== undefined) {
		$('#section-of_pt_bodytype').show();
		$('#section-of_sitebg').show();
		$('#section-of_pt_body_font').show();
		$('#section-of_pt_mscolors').show();
		$('#section-of_pt_primaryclr').show();
		$('#section-of_pt_secondaryclr').show();
		$('#section-of_pt_posttitletype').show();
		$('#section-of_pt_title_font').show();
		$('#section-of_pt_ptaclr').show();
		$('#section-of_pt_ptahovclr').show();
		$('#section-of_pt_widgetcattype').show();
		$('#section-of_pt_widgettitle').show();
		$('#section-of_pt_catclr').show();
		$('#section-of_pt_logoslogantype').show();
		$('#section-of_pt_sloganclr1').show();
		$('#section-of_pt_sloganclr2').show();
		$('#section-of_pt_mnavtype').show();
		$('#section-of_pt_mnactlc').show();
		$('#section-of_pt_mnavclr').show();
		$('#section-of_pt_linkhvrclr').show();
		$('#section-of_pt_fnavtype').show();
		$('#section-of_pt_fnactlc').show();
		$('#section-of_pt_fnavclr').show();
	}	
	
	
});
</script>

<?php
}